#ifndef UU_PACK_H
#define UU_PACK_H

#include "uulib/UUID.h"

void uu_pack(const struct uu *in, uu_t out);
void uu_pack4(const struct uu4 *in, uu_t out);
void uu_pack6(const struct uu6 *in, uu_t out);
void uu_pack7(const struct uu7 *in, uu_t out);

#endif
/* ex:set ts=2 sw=2 itab=spaces: */
